@@ -89,11 +89,13 @@
             return;
         [_foundMedia removeObjectAtIndex:fromIdx];
         [_foundMedia insertObject:object atIndex:toIdx];
-        object.folderTrackNumber = @(toIdx - 1);
-        object = [_foundMedia objectAtIndex:fromIdx];
-        if (![object isKindOfClass:[MLFile class]])
-            return;
-        object.folderTrackNumber = @(fromIdx - 1);
+        int count = 0;
+        for (id object in _foundMedia) {
+            /* _foundMedia may include instances of MLLabel in addition to MLFile, which don't respond to the setter */
+            if ([object respondsToSelector:@selector(setFolderTrackNumber:)]) {
+                [object setFolderTrackNumber:@(count++)];
+            }
+        }
     }
 }
 
